@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # vim: tabstop=8 shiftwidth=8 expandtab
-# $Id: setupmingw32.py,v 1.13 2020/10/15 22:27:08 nanard Exp $
-# the MiniUPnP Project (c) 2007-2020 Thomas Bernard
+# $Id: setupmingw32.py,v 1.14 2021/09/28 21:10:11 nanard Exp $
+# the MiniUPnP Project (c) 2007-2021 Thomas Bernard
 # https://miniupnp.tuxfamily.org/ or http://miniupnp.free.fr/
 #
 # python script to build the miniupnpc module under windows (using mingw32)
@@ -28,8 +28,8 @@ setup(name="miniupnpc",
       url='http://miniupnp.free.fr/',
       description='miniUPnP client',
       ext_modules=[
-         Extension(name="miniupnpc", sources=["miniupnpcmodule.c"],
+         Extension(name="miniupnpc", sources=["src/miniupnpcmodule.c"],
                    libraries=["ws2_32", "iphlpapi"] + compat_lib,
-                   extra_objects=["miniupnpc.lib"])
+                   include_dirs=['include'], extra_objects=["miniupnpc.lib"])
       ])
 
